#
# spec file for package octave-forge-io
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define octpkg  io
Name:           octave-forge-%{octpkg}
Version:        2.4.12
Release:        lp152.2.6
Summary:        Input/Output in external formats from Octave
License:        GPL-3.0-or-later AND BSD-2-Clause
Group:          Productivity/Scientific/Math
Url:            http://octave.sourceforge.net
Source0:        http://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 3.8.0
Requires:       xerces-j2

%description
Input/Output in external formats.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Wed Nov 21 2018 badshah400@gmail.com
- Update to version 2.4.12:
  * Bug fixes:
  - dbfwrite.m: avoid crash and vectorize writing data to file
    (bug #53899)
  - dbfwrite.m: add unwind_protect block to be able to avoid
    dangling file handles in case of errors; better checks on
    data column homogeneity; texinfo (help) header fixes
  - A little more robust Java check
  - csv2cell: improper string indexing (bug #54407), fix by
    Orion Paplowski
  * Code improvements:
  - POI interface: adapt to POI-4.0.0 (new getCelltype enums)
  - POI: overhaul cell type handling when reading and writing
  - dbfread.m: improve speed when reading a subset of data
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 2.4.11:
  * OCT interface: fix reading shared formula results (bug #52875)
  * OCT interface: fix a rare case of nested text cell XML with
    special formatting attributes (bug # 53298)
  * OCT interface: don't over-allocate memory when reading text
    cells in xlsx (bug 533910, credits to Peter Giles
  * OCT interface: return correct date values for .ods file (bug
    [#53401])
  * dbfwrite.m: don't prepend space before string values
  * bug #53510: fix detection of Java version for Java > 8
  * OCT interface: (part of) bug #53459, i.e. reading .xlsx files
    with a more complex mix of chartsheets, macrosheets and
    worksheets, and exploring such files with xlsfinfo. Writing to
    such files however isn't guaranteed to be bug free. However,
    other interfaces (POI, UNO) provide a workaround.
  * COM interface: clearly distinguish between worksheets and e.g.,
    chartsheets when referencing sheets by number.
* Thu Nov  9 2017 badshah400@gmail.com
- Update to version 2.4.8:
  * csv2cell(): Improve ignoring CR (char (13)) in csv files (bugs
    [#50979] and #50297)
  * OCT interface:
  - More robust identification of worksheets (spreadsheets
    written with POI interface were misinterpreted)
  - Overhauled reading .xlsx files; catches more types:
    inlineString, Boolean, ...
  * read_namelist.m: improve reading when ending char is not fist
    on line (bug #52242)
  * Replace utf82unicode with native2unicode v.v. in Octave 4.4+
  * If no filename extension is given, default to .xlsx rather
    than .xls
  * xlsread.m and odsread.m now accept a function handle, an
    output options struct and interface as arguments after the
    third (range) argument, in any order.
  * all spreadsheet I/O functions now accept an empty string as
    worksheet name, implying the first worksheet.
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 2.4.5
  * New functions.
  * Bug fixes.
* Sat Sep 17 2016 dmitry_r@opensuse.org
- Update to version 2.4.3
  * io_xls_testscript.m, io_ods_testscript.m: return results rather
    than bail out when hitting errors
  * cell2csv: increase precision hen writing double values
  * Bug fixes
* Fri Jul  8 2016 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Changed several calls to (now deprecated) octave_config_info into
    calls to __have_feature__.m
  * Add support for complex numbers in read_namelist.m and write_namelist.m
  * Bug fixes
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 2.4.1
  - xmlread.m and xmlwrite.m as replacement of the undocumented,
    unsupported and unusable binary code.
  - New function tidyxml.m:  simply strips characters < 32 or > 126 from
    character arrays or cell arrays (including mixed cell arrays).
  - test_spsh.m now shows a nice summary of test results for each interface.
* Thu Oct 22 2015 dmitry_r@opensuse.org
- Update to version 2.2.11
  * Bug fixes
* Mon Sep 28 2015 dmitry_r@opensuse.org
- Update to version 2.2.10
  * Support for Named Ranges
  * Bug fixes
* Tue Jul 14 2015 dmitry_r@opensuse.org
- Update to version 2.2.9
  * Bug fixes
* Mon Jun 22 2015 dmitry_r@opensuse.org
- Update to version 2.2.8
  * Bug fixes
* Sun Mar  8 2015 dmitry_r@opensuse.org
- Update to version 2.2.7
  * Bug fixes
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.2.6
